@@ -2,10 +2,11 @@ import click
 from dnastack.client import *
 from dnastack.cli.auth import get_oauth_token
 
+from dnastack.cli.utils import get_config
+
 
 @click.group()
-@click.pass_context
-def tables(ctx):
+def tables():
     pass
 
 
@@ -15,11 +16,14 @@ def list_tables(ctx):
     oauth_token = get_oauth_token(ctx)
     try:
         click.echo(
-            dataconnect_client.list_tables(ctx.obj["data-connect-url"], oauth_token)
+            dataconnect_client.list_tables(
+                dataconnect_url=get_config(ctx, "data_connect.url"),
+                oauth_token=oauth_token,
+            )
         )
     except Exception as e:
         click.secho(
-            f"Unable to list tables from url [{ctx.obj['data-connect-url']}]: {e}",
+            f"Unable to list tables from url [{get_config(ctx, 'data_connect.url')}]: {e}",
             fg="red",
         )
         sys.exit(1)
@@ -31,11 +35,13 @@ def list_tables(ctx):
 def get(ctx, table_name):
     try:
         click.echo(
-            dataconnect_client.get_table(ctx.obj["data-connect-url"], table_name)
+            dataconnect_client.get_table(
+                get_config(ctx, "data_connect.url"), table_name
+            )
         )
     except SSLError:
         click.secho(
-            f"Unable to retrieve SSL certificate from {ctx.obj['data-connect-url']}",
+            f"Unable to retrieve SSL certificate from {get_config(ctx, 'data_connect.url')}",
             fg="red",
         )
         sys.exit(1)
