@@ -44,5 +44,7 @@ def download(ctx, urls, output_dir, input_file, quiet):
     try:
         download_files(download_urls, output_dir, quiet=quiet)
     except Exception as e:
-        click.secho(str(e), fg="red")
+        click.secho(
+            f"Unable to execute downloads for urls [{','.join(urls)}]: {e}", fg="red"
+        )
         sys.exit(1)
