@@ -1,3 +1,5 @@
+from urllib.parse import urlparse
+
 import click
 import urllib3
 import threading
@@ -63,6 +65,11 @@ def get_object_id_from_drs(url):
         raise Exception(f"Could not get drs object id from url {url}")
 
 
+def get_filename_from_url(url: str) -> str:
+    parsed_url = urlparse(url)
+    return parsed_url.path.split("/")[-1]
+
+
 def exit_download(url: str, code: int, message: str = "", exit_codes: dict = None):
     if exit_codes is not None:
         exit_code_lock.acquire()
@@ -81,9 +88,7 @@ def download_file(
 
     http = urllib3.PoolManager()
     chunk_size = 1024
-    download_url = url
-    download_file = ""
-    signed_access_ids = ["az-blobstore-signed"]
+    download_url = None
 
     if is_drs_url(url):
         # parse the drs url to the resource url
@@ -113,29 +118,29 @@ def download_file(
             return
 
         if "access_methods" in object_info.keys():
-            for access_method in object_info["access_methods"][0]:
-                if access_method.get("access_id", None):
-                    if access_method["access_id"] in signed_access_ids:
-                        try:
-                            object_access = drs_client.get_object_access(
-                                object_id, access_method["access_id"]
-                            )
-                        except HTTPError as e:
-                            http.clear()
-                            exit_download(
-                                url,
-                                1,
-                                f"Error determining access method: {e}",
-                                exit_codes,
-                            )
-                        download_url = object_access["url"]
-                        break
-
-                # if we have an https, use that
-                if access_method["type"] == "https":
-                    download_url = access_method["access_url"]["url"]
-                    download_file = download_url.split("/")[-1]
+            access_methods = object_info["access_methods"][0]
+            for access_method in [am for am in access_methods if am["type"] == "https"]:
+                # try to use the access_id to get the download url
+                if "access_id" in access_method.keys():
+                    object_access = drs_client.get_object_access(
+                        object_id, access_method["access_id"]
+                    )
+                    download_url = object_access["url"][0]
                     break
+                # if we have a direct access_url for the access_method, use that
+                elif "access_url" in access_method.keys():
+                    download_url = access_method["access_url"]["url"]
+                    break
+
+            if not download_url:
+                # we couldn't find a download url, exit unsuccessful
+                http.clear()
+                exit_download(
+                    url,
+                    1,
+                    f"Error determining access method",
+                    exit_codes,
+                )
         else:
             return  # next page token, just return
     else:
@@ -152,18 +157,20 @@ def download_file(
         )
         return
 
+    download_filename = get_filename_from_url(download_url)
+
     if out is not None:
-        data = handle_file_response(download_file, download_stream.read())
+        data = handle_file_response(download_filename, download_stream.read())
         output_lock.acquire()
-        out = out.append(file_to_dataframe(download_file, data))
+        out.append(file_to_dataframe(download_filename, data))
         output_lock.release()
 
     else:
-        with open(f"{output_dir}/{download_file}", "wb+") as dest:
+        with open(f"{output_dir}/{download_filename}", "wb+") as dest:
             stream_size = int(download_stream.headers["Content-Length"])
             file_stream = download_stream.stream(chunk_size)
             if not quiet:
-                click.echo(f"Downloading {url} into {output_dir}/{download_file}")
+                click.echo(f"Downloading {url} into {output_dir}/{download_filename}")
                 with click.progressbar(
                     length=stream_size, color=True
                 ) as download_progress:
