@@ -27,7 +27,7 @@ TEST_COLLECTION_QUERY = (
 )
 
 # DRS
-TEST_DRS_URLS = (
+drs_urls = (
     os.getenv("E2E_DRS_URLS").split(",")
     if os.getenv("E2E_DRS_URLS")
     else [
@@ -36,14 +36,26 @@ TEST_DRS_URLS = (
         "drs://drs.international.covidcloud.ca/e374d7ff-8944-4a6c-944b-78d40dd96654",
     ]
 )
-TEST_DRS_FILENAMES = (
+drs_filenames = (
     os.getenv("E2E_DRS_FILENAMES").split(",")
     if os.getenv("E2E_DRS_FILENAMES")
     else ["MW592874.fasta", "SRR13820545.fa", "SRR13820554.fa"]
 )
 
-# do a quick check to see if we have the same number of filenames and urls
-assert len(TEST_DRS_FILENAMES) == len(TEST_DRS_URLS)
+TEST_DRS_URLS = drs_urls
+TEST_DRS_FILENAMES = drs_filenames
+
+TEST_DRS = dict(zip(drs_urls, drs_filenames))
+
+TEST_DRS_WITH_ACCESS_URL = (
+    os.getenv("E2E_DRS_ACCESS_URL")
+    or "drs://drs.international.covidcloud.ca/072f2fb6-8240-4b1e-b736-7868f559c795"
+)
+
+TEST_DRS_WITH_ACCESS_ID = (
+    os.getenv("E2E_DRS_ACCESS_ID")
+    or "drs://explorer.alpha.dnastack.com/70cf03ad-1a9b-48e4-b0db-5ef14bf12c3a"
+)
 
 # WES
 TEST_WES_URI = os.getenv("E2E_WES_URI") or "https://workspaces-wes.beta.dnastack.com/"
