@@ -25,19 +25,33 @@ class TestCliAuthCommand(unittest.TestCase):
         self.runner = CliRunner()
         self.data_connect_url = TEST_DATA_CONNECT_URI
         self.collections_url = TEST_COLLECTIONS_URI
-        self.wallet_url = TEST_WALLET_URI
+        self.wallet_url = TEST_AUTH_PARAMS["publisher"]["url"]
 
         clear_config()
-        set_cli_config(self.runner, "data-connect-url", self.data_connect_url)
-        set_cli_config(self.runner, "collections-url", self.collections_url)
-        set_auth_params(
+        set_cli_config(self.runner, "data_connect.url", self.data_connect_url)
+        set_cli_config(self.runner, "collections.url", self.collections_url)
+        set_auth_params_for_service(
             self.runner,
-            TEST_AUTH_PARAMS["publisher"],
+            service="data_connect",
+            auth_params=TEST_AUTH_PARAMS["publisher"],
+        )
+        set_auth_params_for_service(
+            self.runner,
+            service="collections",
+            auth_params=TEST_AUTH_PARAMS["publisher"],
         )
         set_cli_config(
-            self.runner, "oauth_token", ["scope", TEST_AUTH_SCOPES["publisher"]]
+            self.runner,
+            f"oauth|{self.wallet_url}|scope",
+            TEST_AUTH_SCOPES["publisher"],
+            delimiter="|",
+        )
+        login_with_refresh_token_for_service(
+            self.runner, "data-connect", TEST_WALLET_REFRESH_TOKEN["publisher"]
+        )
+        login_with_refresh_token_for_service(
+            self.runner, "collections", TEST_WALLET_REFRESH_TOKEN["publisher"]
         )
-        login_with_refresh_token(self.runner, TEST_WALLET_REFRESH_TOKEN["publisher"])
 
     @staticmethod
     def do_login_steps(proc, auth_test, allow=True):
@@ -85,7 +99,15 @@ class TestCliAuthCommand(unittest.TestCase):
 
     def test_login(self):
         proc = subprocess.Popen(
-            ["python3", "-m", "dnastack", "auth", "login", "--no-browser"],
+            [
+                "python3",
+                "-m",
+                "dnastack",
+                "auth",
+                "login",
+                "data-connect",
+                "--no-browser",
+            ],
             stdout=subprocess.PIPE,
         )
 
@@ -110,8 +132,12 @@ class TestCliAuthCommand(unittest.TestCase):
         )
         self.assertIn("login successful", output.decode("utf-8").lower())
 
-        self.assertIsNotNone(get_cli_config(self.runner, "oauth_token"))
-        token = json.loads(get_cli_config(self.runner, "oauth_token"))
+        self.assertIsNotNone(
+            get_cli_config(self.runner, f"oauth|{self.wallet_url}", delimiter="|")
+        )
+        token = json.loads(
+            get_cli_config(self.runner, f"oauth|{self.wallet_url}", delimiter="|")
+        )
 
         assert_has_property(self, token, "access_token")
         self.access_token = token["access_token"]
@@ -124,26 +150,36 @@ class TestCliAuthCommand(unittest.TestCase):
         jwt_scopes = access_jwt["scope"].split(" ")
         for scope in TEST_AUTH_SCOPES["publisher"].split():
             self.assertIn(scope, jwt_scopes)
-        self.assertEqual(access_jwt["azp"], TEST_AUTH_PARAMS["publisher"]["client_id"])
-        self.assertEqual(access_jwt["iss"], TEST_AUTH_PARAMS["publisher"]["wallet_uri"])
+        self.assertEqual(
+            access_jwt["azp"], TEST_AUTH_PARAMS["publisher"]["client"]["id"]
+        )
+        self.assertEqual(access_jwt["iss"], TEST_AUTH_PARAMS["publisher"]["url"])
         self.assertGreater(access_jwt["exp"], time())
 
     def test_login_no_config(self):
         clear_config()
         result = self.runner.invoke(
             dnastack_cli.dnastack,
-            [
-                "auth",
-                "login",
-            ],
+            ["auth", "login", "data-connect"],
         )
 
         self.assertNotEqual(result.exit_code, 0)
-        self.assertIn("no api urls are configured", result.output.lower())
+        self.assertIn(
+            "[data_connect.wallet] configuration variable is not set",
+            result.output.lower(),
+        )
 
     def test_login_deny(self):
         proc = subprocess.Popen(
-            ["python3", "-m", "dnastack", "auth", "login", "--no-browser"],
+            [
+                "python3",
+                "-m",
+                "dnastack",
+                "auth",
+                "login",
+                "data-connect",
+                "--no-browser",
+            ],
             stdout=subprocess.PIPE,
         )
 
@@ -163,31 +199,35 @@ class TestCliAuthCommand(unittest.TestCase):
         self.assertIn("access denied", output.decode("utf-8").lower())
 
     def test_refresh(self):
-        old_token = json.loads(get_cli_config(self.runner, "oauth_token"))
+        old_token = json.loads(
+            get_cli_config(self.runner, f"oauth|{self.wallet_url}", delimiter="|")
+        )
 
         result = self.runner.invoke(
             dnastack_cli.dnastack,
-            [
-                "auth",
-                "refresh",
-            ],
+            ["auth", "refresh", "data-connect"],
         )
 
         self.assertEqual(result.exit_code, 0)
 
         # make sure the access_token has changed
-        new_token = json.loads(get_cli_config(self.runner, "oauth_token"))
-        self.assertNotEqual(old_token["access_token"], new_token)
+        new_token = json.loads(
+            get_cli_config(self.runner, f"oauth|{self.wallet_url}", delimiter="|")
+        )
+        self.assertNotEqual(old_token["access_token"], new_token["access_token"])
 
     def test_refresh_token_missing_token(self):
-        set_cli_config(self.runner, "oauth_token", ["access_token", ""])
-        set_cli_config(self.runner, "oauth_token", ["refresh_token", ""])
+        wallet_url = get_cli_config(self.runner, "data_connect.wallet.url")
+        set_cli_config(
+            self.runner, f"oauth|{wallet_url}|access_token", "", delimiter="|"
+        )
+        set_cli_config(
+            self.runner, f"oauth|{wallet_url}|refresh_token", "", delimiter="|"
+        )
+
         result = self.runner.invoke(
             dnastack_cli.dnastack,
-            [
-                "auth",
-                "refresh",
-            ],
+            ["auth", "refresh", "data-connect"],
         )
 
         self.assertNotEqual(
@@ -202,14 +242,16 @@ class TestCliAuthCommand(unittest.TestCase):
         self.assertIn("The refresh token does not exist", result.output)
 
     def test_refresh_token_bad_token(self):
-        set_cli_config(self.runner, "oauth_token", ["access_token", ""])
-        set_cli_config(self.runner, "oauth_token", ["refresh_token", "badtoken"])
+        wallet_url = get_cli_config(self.runner, "data_connect.wallet.url")
+        set_cli_config(
+            self.runner, f"oauth|{wallet_url}|access_token", "", delimiter="|"
+        )
+        set_cli_config(
+            self.runner, f"oauth|{wallet_url}|refresh_token", "badtoken", delimiter="|"
+        )
         result = self.runner.invoke(
             dnastack_cli.dnastack,
-            [
-                "auth",
-                "refresh",
-            ],
+            ["auth", "refresh", "data-connect"],
         )
 
         self.assertNotEqual(result.exit_code, 0)
