@@ -7,13 +7,15 @@ from .. import *
 
 class TestClientLibraryFilesCommand(unittest.TestCase):
     def setUp(self):
-        self.publisher_client = PublisherClient(dataconnect_url=TEST_DATA_CONNECT_URI)
+        self.publisher_client = PublisherClient(
+            email=TEST_WALLET_EMAIL,
+            personal_access_token=TEST_WALLET_PERSONAL_ACCESS_TOKEN_PUBLISHER,
+            dataconnect_url=TEST_DATA_CONNECT_URI,
+        )
 
     def test_drs_download(self):
-        self.publisher_client.download(
-            urls=TEST_DRS_URLS[:1],
-            output_dir="out",
-        )
+        drs_url = TEST_DRS_URLS[0]
+        self.publisher_client.download(urls=[drs_url], output_dir="out")
         self.assertTrue(
             pathlib.Path(f"{os.getcwd()}/out/{TEST_DRS_FILENAMES[0]}").exists()
         )
@@ -25,10 +27,7 @@ class TestClientLibraryFilesCommand(unittest.TestCase):
         pathlib.Path(f"{os.getcwd()}/out").rmdir()
 
     def test_multiple_drs_download(self):
-        self.publisher_client.download(
-            urls=TEST_DRS_URLS,
-            output_dir="out",
-        )
+        self.publisher_client.download(urls=TEST_DRS_URLS, output_dir="out")
 
         for drs_file in TEST_DRS_FILENAMES:
             self.assertTrue(pathlib.Path(f"{os.getcwd()}/out/{drs_file}").exists())
